pymodaq_plugins_amplitude (Amplitude Lasers)
############################################

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins.svg
   :target: https://pypi.org/project/pymodaq_plugins_amplitude/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/PyMoDAQ/pymodaq_plugins_amplitude/workflows/Upload%20Python%20Package/badge.svg
    :target: https://github.com/PyMoDAQ/pymodaq_plugins_amplitude

This repository contains a set of PyMoDAQ plugins for Amplitude Systems Lasers


Authors
=======

* _S. J. Weber

Instruments
===========
Below is the list of instruments included in this plugin

Viewer0D
++++++++

* **AmplitudeSystemsCRC16**: Let you control the laser settings and grab info on the laser status (tested on a Satsuma)

